@@ -37,8 +37,10 @@ package URI::gemini {
 }
 
 package Net::Gemini;
-our $VERSION = '0.04';
-use 5.10.0;
+our $VERSION = '0.05';
+use strict;
+use warnings;
+use Encode ();
 use IO::Socket::SSL;
 use Net::SSLeay;
 
@@ -166,7 +168,7 @@ sub get {
                     $obj{_meta} = Encode::decode( 'UTF-8', $obj{_meta}, Encode::FB_CROAK );
                     1;
                 } or do {
-                    @obj{qw(_code _error)} = ( 0, "failed to decode meta" );
+                    @obj{qw(_code _error)} = ( 0, "failed to decode meta: $@" );
                     goto BLESSING;
                 };
                 substr $obj{_buf}, 0, $len + 2, '';    # +2 for the \r\n
@@ -178,7 +180,8 @@ sub get {
                 @obj{qw(_code _error)} = ( 0, "meta is too long" );
                 goto BLESSING;
             }
-            my $n = sysread $obj{_socket}, my $buf, $bufsize;
+            my $buf;
+            my $n = sysread $obj{_socket}, $buf, $bufsize;
             unless ( defined $n ) {
                 @obj{qw(_code _error)} = ( 0, "recv response failed: $!" );
                 goto BLESSING;
@@ -192,7 +195,7 @@ sub get {
     }
 
   BLESSING:
-    close $obj{_socket} if $obj{_code} != 2;
+    close $obj{_socket} if defined $obj{_socket} and $obj{_code} != 2;
     bless( \%obj, $class ), $obj{_code};
 }
 
@@ -208,7 +211,8 @@ sub getmore {
 
     my $bufsize = $param{bufsize} || 4096;
     while (1) {
-        $len = sysread $self->{_socket}, my $buf, $bufsize;
+        my $buf;
+        $len = sysread $self->{_socket}, $buf, $bufsize;
         if ( !defined $len ) {
             die "sysread failed: $!\n";
         } elsif ( $len == 0 ) {
